==> haskell-hspec-discover-2.7.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.7.1
id: hspec-discover-2.7.1-LGJDqSQ2jlrBzGstAgoI3G
key: hspec-discover-2.7.1-LGJDqSQ2jlrBzGstAgoI3G
license: MIT
copyright: (c) 2012-2019 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: ab530947f0abcc44f3ca7238faa68053
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-discover-2.7.1
hs-libraries: HShspec-discover-2.7.1-LGJDqSQ2jlrBzGstAgoI3G
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.7.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.7.1
id: hspec-discover-2.7.1-FiDvOpHbj5848m5NCuFKmS
key: hspec-discover-2.7.1-FiDvOpHbj5848m5NCuFKmS
license: MIT
copyright: (c) 2012-2019 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: 21942f3df9f7d1165f8cb1637f9d5493
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/hspec-discover-2.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hspec-discover-2.7.1
hs-libraries: HShspec-discover-2.7.1-FiDvOpHbj5848m5NCuFKmS
depends:
    base-4.12.0.0 directory-1.3.3.0 filepath-1.4.2.1
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
